@@ -33,7 +33,7 @@ class Waffle(Widget):
         self._waffle_pixels = {}
         self._canvas = None
 
-        super(Waffle, self).__init__(master, tk, grid, align, visible, enabled, width, height)
+        super().__init__(master, tk, grid, align, visible, enabled, width, height)
 
         if bg is not None:
             self.bg = bg
@@ -295,7 +295,7 @@ class Waffle(Widget):
     def __getitem__(self, index):
         return self._waffle_pixels[index]
 
-class WafflePixel():
+class WafflePixel:
     def __init__(self, x, y, canvas, canvas_x, canvas_y, size, dotty, color):
         self._x = x
         self._y = y
