@@ -1,9 +1,9 @@
 import pytest
 from time import sleep
 
-@pytest.yield_fixture(autouse=True)
+@pytest.fixture(autouse=True)
 def delay():
     # put a small delay in before every test,
     #  otherwise tkinter can get upset by the constant
     #  creating and destroying of apps
-    sleep(0.1)
\ No newline at end of file
+    sleep(0.1)
